'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function createObserver(initialValue) {
    var key = 0;
    var value = initialValue;
    var subscribers = {};
    return [
        function update(newValue) {
            value = newValue;
            for (var k in subscribers) {
                subscribers[k](value);
            }
        },
        function subscribe(callback) {
            subscribers[key] = callback;
            return key++;
        },
        function unsubscribe(listenerKey) {
            delete subscribers[listenerKey];
        },
    ];
}

function joinClassNames() {
    var classNames = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        classNames[_i] = arguments[_i];
    }
    return classNames
        .filter(function (className) { return typeof className === "string"; })
        .join(" ");
}
function removeChildren(parent) {
    while (parent.lastChild) {
        parent.removeChild(parent.lastChild);
    }
}
function preventDefault(e) {
    e.preventDefault();
}
function enableScroll(target) {
    target.removeEventListener("mousewheel", preventDefault);
    target.removeEventListener("touchmove", preventDefault);
}
function disableScroll(target) {
    target.addEventListener("mousewheel", preventDefault, {
        passive: false
    });
    target.addEventListener("touchmove", preventDefault, {
        passive: false
    });
}

function testRegExp(str, regExp) {
    return regExp.test(str);
}
function matchRegExp(str, regExp) {
    var matches = str.match(regExp);
    return matches === null ? [] : matches;
}
function removeRegExp(str, regExp) {
    return str.replace(regExp, "");
}
function isEmail(str) {
    return testRegExp(str, /^[^\s@"]{1,64}@[^\s@_]+$/);
}
function matchNumber(str) {
    return matchRegExp(str, /\d/g);
}
function removeWhitespace(str) {
    return removeRegExp(str, /\s/g);
}
function removeXmlTag(str) {
    return removeRegExp(str, /<[^>]*>/g);
}
function removeCharacterReference(str) {
    return removeRegExp(str, /&[^;]+;/g);
}

function createElement(tagName, builder) {
    var element = document.createElement(tagName);
    builder && builder(element);
    return element;
}
function createAnchor(builder) {
    return createElement("a", builder);
}
function createAbbr(builder) {
    return createElement("abbr", builder);
}
function createAddress(builder) {
    return createElement("address", builder);
}
function createArea(builder) {
    return createElement("area", builder);
}
function createArticle(builder) {
    return createElement("article", builder);
}
function createAside(builder) {
    return createElement("aside", builder);
}
function createAudio(builder) {
    return createElement("audio", builder);
}
function createBold(builder) {
    return createElement("b", builder);
}
function createBase(builder) {
    return createElement("base", builder);
}
function createBdi(builder) {
    return createElement("bdi", builder);
}
function createBdo(builder) {
    return createElement("bdo", builder);
}
function createBlockquote(builder) {
    return createElement("blockquote", builder);
}
function createBody(builder) {
    return createElement("body", builder);
}
function createBr(builder) {
    return createElement("br", builder);
}
function createButton(builder) {
    return createElement("button", builder);
}
function createCanvas(builder) {
    return createElement("canvas", builder);
}
function createCaption(builder) {
    return createElement("caption", builder);
}
function createCite(builder) {
    return createElement("cite", builder);
}
function createCode(builder) {
    return createElement("code", builder);
}
function createCol(builder) {
    return createElement("col", builder);
}
function createColGroup(builder) {
    return createElement("colgroup", builder);
}
function createData(builder) {
    return createElement("data", builder);
}
function createDataList(builder) {
    return createElement("datalist", builder);
}
function createDd(builder) {
    return createElement("dd", builder);
}
function createDel(builder) {
    return createElement("del", builder);
}
function createDetails(builder) {
    return createElement("details", builder);
}
function createDfn(builder) {
    return createElement("dfn", builder);
}
function createDiv(builder) {
    return createElement("div", builder);
}
function createDl(builder) {
    return createElement("dl", builder);
}
function createDt(builder) {
    return createElement("dt", builder);
}
function createEm(builder) {
    return createElement("em", builder);
}
function createEmbed(builder) {
    return createElement("embed", builder);
}
function createFieldSet(builder) {
    return createElement("fieldset", builder);
}
function createFigcaption(builder) {
    return createElement("figcaption", builder);
}
function createFigure(builder) {
    return createElement("figure", builder);
}
function createFooter(builder) {
    return createElement("footer", builder);
}
function createForm(builder) {
    return createElement("form", builder);
}
function createH1(builder) {
    return createElement("h1", builder);
}
function createH2(builder) {
    return createElement("h2", builder);
}
function createH3(builder) {
    return createElement("h3", builder);
}
function createH4(builder) {
    return createElement("h4", builder);
}
function createH5(builder) {
    return createElement("h5", builder);
}
function createH6(builder) {
    return createElement("h6", builder);
}
function createHead(builder) {
    return createElement("head", builder);
}
function createHeader(builder) {
    return createElement("header", builder);
}
function createHr(builder) {
    return createElement("hr", builder);
}
function createHtml(builder) {
    return createElement("html", builder);
}
function createIdiomatic(builder) {
    return createElement("i", builder);
}
function createIFrame(builder) {
    return createElement("iframe", builder);
}
function createImg(builder) {
    return createElement("img", builder);
}
function createInput(builder) {
    return createElement("input", builder);
}
function createIns(builder) {
    return createElement("ins", builder);
}
function createKbd(builder) {
    return createElement("kbd", builder);
}
function createLabel(builder) {
    return createElement("label", builder);
}
function createLegend(builder) {
    return createElement("legend", builder);
}
function createLi(builder) {
    return createElement("li", builder);
}
function createLink(builder) {
    return createElement("link", builder);
}
function createMain(builder) {
    return createElement("main", builder);
}
function createMap(builder) {
    return createElement("map", builder);
}
function createMark(builder) {
    return createElement("mark", builder);
}
function createMenu(builder) {
    return createElement("menu", builder);
}
function createMeta(builder) {
    return createElement("meta", builder);
}
function createMeter(builder) {
    return createElement("meter", builder);
}
function createNav(builder) {
    return createElement("nav", builder);
}
function createNoScript(builder) {
    return createElement("noscript", builder);
}
function createObject(builder) {
    return createElement("object", builder);
}
function createOl(builder) {
    return createElement("ol", builder);
}
function createOptGroup(builder) {
    return createElement("optgroup", builder);
}
function createOption(builder) {
    return createElement("option", builder);
}
function createOutput(builder) {
    return createElement("output", builder);
}
function createParagraph(builder) {
    return createElement("p", builder);
}
function createParam(builder) {
    return createElement("param", builder);
}
function createPicture(builder) {
    return createElement("picture", builder);
}
function createPre(builder) {
    return createElement("pre", builder);
}
function createProgress(builder) {
    return createElement("progress", builder);
}
function createQuote(builder) {
    return createElement("q", builder);
}
function createRp(builder) {
    return createElement("rp", builder);
}
function createRt(builder) {
    return createElement("rt", builder);
}
function createRuby(builder) {
    return createElement("ruby", builder);
}
function createStrikethrough(builder) {
    return createElement("s", builder);
}
function createSamp(builder) {
    return createElement("samp", builder);
}
function createScript(builder) {
    return createElement("script", builder);
}
function createSection(builder) {
    return createElement("section", builder);
}
function createSelect(builder) {
    return createElement("select", builder);
}
function createSlot(builder) {
    return createElement("slot", builder);
}
function createSmall(builder) {
    return createElement("small", builder);
}
function createSource(builder) {
    return createElement("source", builder);
}
function createSpan(builder) {
    return createElement("span", builder);
}
function createStrong(builder) {
    return createElement("strong", builder);
}
function createStyle(builder) {
    return createElement("style", builder);
}
function createSub(builder) {
    return createElement("sub", builder);
}
function createSummary(builder) {
    return createElement("summary", builder);
}
function createSup(builder) {
    return createElement("sup", builder);
}
function createTable(builder) {
    return createElement("table", builder);
}
function createTBody(builder) {
    return createElement("tbody", builder);
}
function createTd(builder) {
    return createElement("td", builder);
}
function createTemplate(builder) {
    return createElement("template", builder);
}
function createTextarea(builder) {
    return createElement("textarea", builder);
}
function createTFoot(builder) {
    return createElement("tfoot", builder);
}
function createTh(builder) {
    return createElement("th", builder);
}
function createTHead(builder) {
    return createElement("thead", builder);
}
function createTime(builder) {
    return createElement("time", builder);
}
function createTitle(builder) {
    return createElement("title", builder);
}
function createTr(builder) {
    return createElement("tr", builder);
}
function createTrack(builder) {
    return createElement("track", builder);
}
function createUnarticulatedAnnotation(builder) {
    return createElement("u", builder);
}
function createUl(builder) {
    return createElement("ul", builder);
}
function createVar(builder) {
    return createElement("var", builder);
}
function createVideo(builder) {
    return createElement("video", builder);
}
function createWbr(builder) {
    return createElement("wbr", builder);
}

exports.createAbbr = createAbbr;
exports.createAddress = createAddress;
exports.createAnchor = createAnchor;
exports.createArea = createArea;
exports.createArticle = createArticle;
exports.createAside = createAside;
exports.createAudio = createAudio;
exports.createBase = createBase;
exports.createBdi = createBdi;
exports.createBdo = createBdo;
exports.createBlockquote = createBlockquote;
exports.createBody = createBody;
exports.createBold = createBold;
exports.createBr = createBr;
exports.createButton = createButton;
exports.createCanvas = createCanvas;
exports.createCaption = createCaption;
exports.createCite = createCite;
exports.createCode = createCode;
exports.createCol = createCol;
exports.createColGroup = createColGroup;
exports.createData = createData;
exports.createDataList = createDataList;
exports.createDd = createDd;
exports.createDel = createDel;
exports.createDetails = createDetails;
exports.createDfn = createDfn;
exports.createDiv = createDiv;
exports.createDl = createDl;
exports.createDt = createDt;
exports.createEm = createEm;
exports.createEmbed = createEmbed;
exports.createFieldSet = createFieldSet;
exports.createFigcaption = createFigcaption;
exports.createFigure = createFigure;
exports.createFooter = createFooter;
exports.createForm = createForm;
exports.createH1 = createH1;
exports.createH2 = createH2;
exports.createH3 = createH3;
exports.createH4 = createH4;
exports.createH5 = createH5;
exports.createH6 = createH6;
exports.createHead = createHead;
exports.createHeader = createHeader;
exports.createHr = createHr;
exports.createHtml = createHtml;
exports.createIFrame = createIFrame;
exports.createIdiomatic = createIdiomatic;
exports.createImg = createImg;
exports.createInput = createInput;
exports.createIns = createIns;
exports.createKbd = createKbd;
exports.createLabel = createLabel;
exports.createLegend = createLegend;
exports.createLi = createLi;
exports.createLink = createLink;
exports.createMain = createMain;
exports.createMap = createMap;
exports.createMark = createMark;
exports.createMenu = createMenu;
exports.createMeta = createMeta;
exports.createMeter = createMeter;
exports.createNav = createNav;
exports.createNoScript = createNoScript;
exports.createObject = createObject;
exports.createObserver = createObserver;
exports.createOl = createOl;
exports.createOptGroup = createOptGroup;
exports.createOption = createOption;
exports.createOutput = createOutput;
exports.createParagraph = createParagraph;
exports.createParam = createParam;
exports.createPicture = createPicture;
exports.createPre = createPre;
exports.createProgress = createProgress;
exports.createQuote = createQuote;
exports.createRp = createRp;
exports.createRt = createRt;
exports.createRuby = createRuby;
exports.createSamp = createSamp;
exports.createScript = createScript;
exports.createSection = createSection;
exports.createSelect = createSelect;
exports.createSlot = createSlot;
exports.createSmall = createSmall;
exports.createSource = createSource;
exports.createSpan = createSpan;
exports.createStrikethrough = createStrikethrough;
exports.createStrong = createStrong;
exports.createStyle = createStyle;
exports.createSub = createSub;
exports.createSummary = createSummary;
exports.createSup = createSup;
exports.createTBody = createTBody;
exports.createTFoot = createTFoot;
exports.createTHead = createTHead;
exports.createTable = createTable;
exports.createTd = createTd;
exports.createTemplate = createTemplate;
exports.createTextarea = createTextarea;
exports.createTh = createTh;
exports.createTime = createTime;
exports.createTitle = createTitle;
exports.createTr = createTr;
exports.createTrack = createTrack;
exports.createUl = createUl;
exports.createUnarticulatedAnnotation = createUnarticulatedAnnotation;
exports.createVar = createVar;
exports.createVideo = createVideo;
exports.createWbr = createWbr;
exports.disableScroll = disableScroll;
exports.enableScroll = enableScroll;
exports.isEmail = isEmail;
exports.joinClassNames = joinClassNames;
exports.matchNumber = matchNumber;
exports.matchRegExp = matchRegExp;
exports.removeCharacterReference = removeCharacterReference;
exports.removeChildren = removeChildren;
exports.removeRegExp = removeRegExp;
exports.removeWhitespace = removeWhitespace;
exports.removeXmlTag = removeXmlTag;
exports.testRegExp = testRegExp;
